# Welcome to **DataBase-Controller**

## Install **SQL**ite

```sh
python -m pip install "dbcontroller[sqlite]"
```

## Install Postgre**SQL**

```sh
python -m pip install "dbcontroller[sql]" "databases[postgresql]"
```

## Install My**SQL**

```sh
python -m pip install "dbcontroller[sql]" "databases[mysql]"
```

## Install **Mongo**

```sh
python -m pip install "dbcontroller[mongo]"
```

## Install **Testing**

```sh
python -m pip install "dbcontroller[testing]"
```

## To Be Used With . . .

- [sqlalchemy](https://pypi.org/project/SQLAlchemy/) and [databases](https://pypi.org/project/databases/)
- [pymongo](https://pypi.org/project/pymongo/) and [motor](https://pypi.org/project/motor/)

## Links

- ### [PyPi](https://pypi.org/project/dbcontroller)
- ### [Github](https://github.com/hlop3z/dbcontroller)
- ### [Read the Documents](https://hlop3z.github.io/dbcontroller/)
